%-----------------------------------------------------------------------------------------------------------------------------------------------------
%				                               PASSE BAS  RIF 
%			Calcul des M+1 coefficients a0 a1 a2 ...aM  d'un filtres RIF passe-bas
%	                          											                                                      Master SET 
%-----------------------------------------------------------------------------------------------------------------------------------------------------
% Formules de quelques fentres classiques intressantes  tester
%(0.54*ones(1,M+1)+(1-0.54)*cos(2*pi*(k-M/2)/(M+1))); 											%Hamming
%(0.5*ones(1,M+1)+0.5*cos(2*pi*(k-M/2)/(M+1)));														%Hanning
%(0.42*ones(1,M+1)-0.5*cos(2*pi*k/(M+1))+0.08*cos(4*pi*k/(M+1)));								%blackman
%(0.42323*ones(1,M+1)-0.49755*cos(2*pi*k/(M+1))+0.07922*cos(4*pi*k/(M+1)));				%blackman Harris
%(7938/18608*ones(1,M+1)-9240/18608*cos(2*pi*k/(M+1))+1430/18608*cos(4*pi*k/(M+1)));	%blackman exacte
%(0.2810639*ones(1,M+1)-0.5208972*cos(2*pi*k/(M+1))+0.1980399*cos(4*pi*k/(M+1)));		%toit plat
%(besseli(0,9*sqrt(1-(4*(k-M/2).*(k-M/2))/((M)^2)))/besseli(0,9));							%kaiser
% exp(k/(M+1));																								%exponentielle
% exp(-1*(k/(M+1)).^2);																						%gauss
%--------------------------------------------------------------------------------------------------------------------------------------------------------------

close all;																			
clear all;
hold off;

fc=4000;					 															% f coupure du filtre
fe=11025;																			% f echantillonnage
M=100; 																				% M+1 coefficients avec  M pair

%Calcul des coeff a --------------------------------------------------------------------------------------------------------------------------------------
k=[0:M];
a=2*fc/fe*sinc(2*fc/fe*(k-M/2));												% sinus cardinal: sinc(x) = sin(pi*x)/pi*x
a=a.*(0.54*ones(1,M+1)+(1-0.54)*cos(2*pi*(k-M/2)/(M+1))); 			%Hamming

%Contrle des performances --------------------------------------------------------------------------------------------------------------------------
[H,freq]=freqz(a,1,1000,11025);												% Calcul de la transmittance H avec les coeff a ci-dessus

%Affichage graphique ----------------------------------------------------------------------------------------------------------------------------------
figure(1)
subplot(2,2,1);
plot(k,a,'+-');																	% Affichage graphique des coefficients  ak
subplot(2,2,2);
plot(freq,abs(H));																% module de |H|	
subplot(2,2,3);
plot(freq,20*log10(abs(H)));													% Bode 20log(|H|)
subplot(2,2,4);
plot(freq,unwrap(angle(H)));													% Bode Phase
   
%Test sur un fichier sonore-----------------------------------------------------------------------------------------------------------------------------
[y1,fe,bits] = wavread('guitare.wav');										% y1 reoit les chantillons sonore
y1=y1';
siz=length(y1);
Te=1/fe;
n=[0:1:(siz-1)];

y2=sin((2*pi*5000/fe)*n);														%fabrication d'un parasite 5000Hz (sifflement)

y2=y1+y2;																			%y2  (musique+sifflement) 

sys=filt(a,1);																		% synthse du filtre par une fonction matlab
y3=lsim(sys,y2,n);																%y3  = signal y2 filtr par une fonction matlab

%Affichage des signaux y1(original), y2(parasit) et  y3(aprs filtrage) en fonction du temps--------------------------------
figure(2);
subplot(3,1,1);
plot(n,y1);			
subplot(3,1,2);
plot(n,y2);
subplot(3,1,3);
plot (n,y3);

%Pour couter les sigaux y1, y2, et y3 appuyer sur une touche aprs chaque morceau---------------------------------------------
%soundsc(y1,fe);
%pause;
soundsc(y2,fe);    
pause;
soundsc(y3,fe);

%MISE au format Q15:  les coeff sont multiplis par 2^15----------------------------------------------------------------------------
%Sauvegarde en hexadcimal dans le fichier ASCII PasseBasbxx_xxxx.txt  pour programme DSP 

coeff= hex16(round(a*32768));										%   hex16.m  est dans le fichier filtre.zip				   
nom=sprintf('PasseBas%d_%d.txt',length(a),fc);				% fabrication du nom de fichier
fid = fopen(nom,'w');												%ouverture du fichier en criture
for i=1:length(a)
	fprintf(fid,'0x%s, ',coeff(i,:));							%criture du fichier
end   
fclose(fid);  															%fermeture du fichier

